==> haskell-fgl-5.6.0.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.6.0.0
id: fgl-5.6.0.0-IGmeQfkpQmd48thU3Ee01i
key: fgl-5.6.0.0-IGmeQfkpQmd48thU3Ee01i
license: BSD-3-Clause
maintainer: Ivan.Miljenovic@gmail.com
author: Martin Erwig, Ivan Lazar Miljenovic
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
abi: 1a2555e0a79bd8ac00a7d9ff8714fb7c
exposed: True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree
hidden-modules: Paths_fgl
import-dirs: /usr/lib/ghc-8.4.3/site-local/fgl-5.6.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/fgl-5.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/fgl-5.6.0.0
hs-libraries: HSfgl-5.6.0.0-IGmeQfkpQmd48thU3Ee01i
depends:
    base-4.11.1.0 transformers-0.5.5.0 array-0.5.2.0
    containers-0.5.11.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-5.6.0.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.6.0.0
id: fgl-5.6.0.0-DFXUL8lX5RsomNdb2OJOi
key: fgl-5.6.0.0-DFXUL8lX5RsomNdb2OJOi
license: BSD-3-Clause
maintainer: Ivan.Miljenovic@gmail.com
author: Martin Erwig, Ivan Lazar Miljenovic
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
abi: caab577dbc62028aa6c02006aee2bd4f
exposed: True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree
hidden-modules: Paths_fgl
import-dirs: /usr/lib/ghc-8.6.1/site-local/fgl-5.6.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/fgl-5.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/fgl-5.6.0.0
hs-libraries: HSfgl-5.6.0.0-DFXUL8lX5RsomNdb2OJOi
depends:
    array-0.5.2.0 base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
